"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var colours_1 = require("./colours");
var utils_1 = require("./utils");
function repeat(text, count) {
    var result = '';
    for (var i = 0; i < count; i++) {
        result += text;
    }
    return result;
}
exports.repeat = repeat;
function increaseIndent(text, indent) {
    var indentPadding = repeat(' ', indent);
    return indentPadding + text.split('\n').join('\n' + indentPadding);
}
exports.increaseIndent = increaseIndent;
function pluralise(count, singular, plural) {
    return count + " " + (count === 1 ? singular : plural);
}
exports.pluralise = pluralise;
function formatPath(root, path) {
    return colours_1.magenta(root) + path
        .map(function (component) {
        if (typeof component === 'number') {
            return colours_1.yellow('[') + colours_1.red("" + component) + colours_1.yellow(']');
        }
        else if (/^[$a-z_][$a-z_0-9]*$/i.test(component)) {
            return colours_1.yellow('.') + colours_1.cyan(component);
        }
        else {
            return colours_1.yellow('[') + colours_1.red("'" + component.replace('\\', '\\\\').replace('\'', '\\\'') + "'") + colours_1.yellow(']');
        }
    })
        .join('');
}
exports.formatPath = formatPath;
function formatErrorResultMessage(prefix, root, errors) {
    return colours_1.white(colours_1.bgRed(colours_1.bold("" + prefix + errors.length + " validation error" + (errors.length === 1 ? '' : 's') + ":"))) + '\n' +
        errors.map(function (error) { return increaseIndent(error.toString(root), 4); }).join('\n');
}
exports.formatErrorResultMessage = formatErrorResultMessage;
function formatEitherValidationErrorMessages(errorsPerType) {
    return utils_1.keysOf(errorsPerType)
        .map(function (desc) {
        var errors = errorsPerType[desc];
        return increaseIndent(colours_1.bold(colours_1.red("Not " + desc + ", due to " + pluralise(errors.length, 'validation error', 'validation errors') + ":")) + '\n' +
            errors.map(function (error) { return increaseIndent(error.toString(), 4); }).join('\n'), 4);
    })
        .join('\n');
}
exports.formatEitherValidationErrorMessages = formatEitherValidationErrorMessages;
function concatenateItems(items, conjunction) {
    if (conjunction === void 0) { conjunction = 'and'; }
    if (items.length === 0)
        return '';
    if (items.length === 1)
        return items[0];
    if (items.length === 2)
        return items[0] + " " + conjunction + " " + items[1];
    return items.slice(0, items.length - 1).join(', ') + ", " + conjunction + " " + items[items.length - 1];
}
exports.concatenateItems = concatenateItems;
//# sourceMappingURL=formatting.js.map